@@ -22,12 +22,10 @@
 #define KCONTACTS_SECRECY_H
 
 #include "kcontacts_export.h"
-#include <QtCore/QVector>
-#include <QtCore/QSharedDataPointer>
-
-namespace KContacts
-{
+#include <QVector>
+#include <QSharedDataPointer>
 
+namespace KContacts {
 class KCONTACTS_EXPORT Secrecy
 {
     friend KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &, const Secrecy &);
@@ -121,7 +119,6 @@ KCONTACTS_EXPORT QDataStream &operator<<(QDataStream &stream, const Secrecy &sec
  * Initializes the @p secrecy object from the @p stream.
  */
 KCONTACTS_EXPORT QDataStream &operator>>(QDataStream &stream, Secrecy &secrecy);
-
 }
 Q_DECLARE_TYPEINFO(KContacts::Secrecy, Q_MOVABLE_TYPE);
 #endif
